(function($){
    'use strict';

    const containerId = 'ztoast-container';
    const styleId = 'ztoast-stylesheet';
    const contentClass = 'ztoast-content';
    const fadeTime = 500;
    const defaultDuration = 2000;
    const onClickClose = true;

    function createContainer(){
        return $('<div>')
                    .attr('id', containerId)
                    .appendTo('body');
    }

    function addStylesheet(){
        const css = `
            #ztoast-container{
              width: 322px;
              position: fixed;
              right: 10px;
              bottom: 0;
              cursor: default;
              color: #fff;
              font-size: 14px;
              z-index: 9999;
              line-height: 20px;
              font-family: 'Roboto', 'Open sans', arial, sans-serif;
            }
            .ztoast-content{
              padding: 14px 10px;
              margin-bottom: 10px;
              background: #323232;
              border-radius: 2px;
              box-shadow: 0 2px 5px 0 rgba(0,0,0,.26);
            }`;

        $('<style>')
            .attr('id', styleId)
            .text(css)
            .appendTo('head');
    }

    function isStylesheetAdded(){
        return !!$('#'+styleId).length;
    }

    function getContainer(){
        const container = $('#'+containerId);

        if(!isStylesheetAdded()){
            addStylesheet();
        }

        if(!container.length){
            return createContainer();
        } else {
            return container;
        }
    }

    function createToast(text){
        return $('<div>')
                    .addClass(contentClass)
                    .text(text);
    }

    function showToast(text, duration){
        const toast = createToast(text);
        const container = getContainer();
        duration = duration || defaultDuration;

        toast
            .css('display', 'none')
            .appendTo(container);

        const closeToast = () => {
            closeAndRemoveToast(toast);
        };

        let timeout;

        toast.fadeIn(fadeTime, ()=>{
             timeout = setTimeout(closeToast, duration);
        });

        if(onClickClose){
            toast.click(closeToast);
            clearTimeout(timeout);
        }

        return {
            close: closeToast
        };
    }

    function closeAndRemoveToast(toastElement){
        toastElement.fadeOut(fadeTime, ()=> { 
            toastElement.remove();
        });
    }

    $.toast = function() {
        showToast.apply(undefined, arguments);
    };

})(jQuery);